==> haskell-incremental-parser-0.5.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-LvIL9c0I7Tv2VMYmRpC4hj
key:                  incremental-parser-0.5.1-LvIL9c0I7Tv2VMYmRpC4hj
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  4aa35cc6478c8fdd6b982f76a484320c
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-LvIL9c0I7Tv2VMYmRpC4hj
depends:
    base-4.17.2.1 input-parsers-0.3.0.2-Jd39pp6tNZL5rUQ1VMfhMp
    logict-0.7.1.0-GwXyMxqvqDHKoFcBRhqDz3
    monoid-subclasses-1.2.6-5n1REWH5m8S1EfVe1Yx85u
    parsers-0.12.12-DSXrb12WW9pAlDntPLXdEB
    rank2classes-1.5.4-4My9blzsufu3dNLzehJ6LI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.5.1-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 incremental-parser
version:              0.5.1
visibility:           public
id:                   incremental-parser-0.5.1-2HJAAXIXSAOHZJnZjW8umu
key:                  incremental-parser-0.5.1-2HJAAXIXSAOHZJnZjW8umu
license:              GPL-3.0-only
copyright:            (c) 2011-2023 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  61e42e7fc7e539737140dec9aa32bdfc
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/incremental-parser-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-incremental-parser
hs-libraries:         HSincremental-parser-0.5.1-2HJAAXIXSAOHZJnZjW8umu
depends:
    base-4.17.2.1 input-parsers-0.3.0.2-LwFmjDJoAFVGUpVC5PEItv
    logict-0.7.1.0-DgJc6ddXzUf1bPXT9IOQ5j
    monoid-subclasses-1.2.6-IlXJkYMqn6oE7pT7lvhP2L
    parsers-0.12.12-5OyYB0LWB7z3XJTkbw3KeS
    rank2classes-1.5.4-EeZ3tYveKjzFOq51UTWJBq transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
